package
module
Version:
v0.0.0-...-5a18b7a
Opens a new window with list of versions in this module.
Published: Nov 27, 2025
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
Documentation
¶
Package plugin 提供 trpc 启动配置中的 plugin 工具
func Bind[T any](typ, name string, target *T)
Bind 将 plugins 配置与本地存储绑定
Register 注册 plugin 配置。请在 init 阶段调用或 NewServer 之前调用。
type Option func(*options)
WithDependsOn 指定 plugin 的强依赖关系
WithFlexDependsOn 指定 plugin 的弱依赖关系
Source Files
¶
Click to show internal directories.
Click to hide internal directories.